Index: /trunk/src/VBox/VMM/EM.cpp
===================================================================
--- /trunk/src/VBox/VMM/EM.cpp	(revision 317)
+++ /trunk/src/VBox/VMM/EM.cpp	(revision 318)
@@ -81,5 +81,5 @@
 static int emR3RawForcedActions(PVM pVM, PCPUMCTX pCtx);
 static int emR3RawExecute(PVM pVM, bool *pfFFDone);
-DECLINLINE(int) emR3RawExecuteInstruction(PVM pVM, const char *pszPrefix, int gcret = VINF_SUCCESS);
+DECLINLINE(int) emR3RawExecuteInstruction(PVM pVM, const char *pszPrefix, int rcGC = VINF_SUCCESS);
 static int emR3HighPriorityPostForcedActions(PVM pVM, int rc);
 static int emR3ForcedActions(PVM pVM, int rc);
@@ -950,12 +950,12 @@
  *
  * @param   pVM         VM handle.
  * @param   gcret       GC return code
  * @param   pszPrefix   Disassembly prefix. If not NULL we'll disassemble the
  *                      instruction and prefix the log output with this text.
  */
 #ifdef LOG_ENABLED
-static int emR3RawExecuteInstructionWorker(PVM pVM, int gcret, const char *pszPrefix)
+static int emR3RawExecuteInstructionWorker(PVM pVM, int rcGC, const char *pszPrefix)
 #else
-static int emR3RawExecuteInstructionWorker(PVM pVM, int gcret)
+static int emR3RawExecuteInstructionWorker(PVM pVM, int rcGC)
 #endif
 {
@@ -1018,6 +1018,5 @@
                 }
 #if 0 /** @note no noticable change; revisit later when we can emulate iret ourselves. */
-                else
-                if (gcret == VINF_PATM_PENDING_IRQ_AFTER_IRET)
+                else if (rcGC == VINF_PATM_PENDING_IRQ_AFTER_IRET)
                 {
                     /* special case: iret, that sets IF,  detected a pending irq/event */
@@ -1111,12 +1110,12 @@
  * @param   pszPrefix   Disassembly prefix. If not NULL we'll disassemble the
  *                      instruction and prefix the log output with this text.
  * @param   gcret       GC return code
  */
-DECLINLINE(int) emR3RawExecuteInstruction(PVM pVM, const char *pszPrefix, int gcret)
+DECLINLINE(int) emR3RawExecuteInstruction(PVM pVM, const char *pszPrefix, int rcGC)
 {
 #ifdef LOG_ENABLED
-    return emR3RawExecuteInstructionWorker(pVM, gcret, pszPrefix);
+    return emR3RawExecuteInstructionWorker(pVM, rcGC, pszPrefix);
 #else
-    return emR3RawExecuteInstructionWorker(pVM, gcret);
+    return emR3RawExecuteInstructionWorker(pVM, rcGC);
 #endif
 }
@@ -950,12 +950,12 @@
  *
  * @param   pVM         VM handle.
- * @param   gcret       GC return code
+ * @param   rcGC        GC return code
  * @param   pszPrefix   Disassembly prefix. If not NULL we'll disassemble the
  *                      instruction and prefix the log output with this text.
@@ -1111,12 +1110,12 @@
  * @param   pszPrefix   Disassembly prefix. If not NULL we'll disassemble the
  *                      instruction and prefix the log output with this text.
- * @param   gcret       GC return code
+ * @param   rcGC        GC return code
  */
